@@ -7,12 +7,15 @@ $C_n$ is a path with its two end-nodes connected.
 from typing import Union, Iterable, Any
 
 from networkx import MultiDiGraph, cycle_graph
+from tqdm import tqdm
 
 __all__ = ["labeled_cycle_graph"]
 
 
 def labeled_cycle_graph(
-    number_of_nodes: Union[int, Iterable[Any]], edge_label: str = "a"
+    number_of_nodes: Union[int, Iterable[Any]],
+    edge_label: str = "a",
+    verbose: bool = True,
 ) -> MultiDiGraph:
     """Returns a cycle graph $C_n$
     of cyclically connected nodes.
@@ -29,12 +32,17 @@ def labeled_cycle_graph(
     edge_label: str
         Label that will be used to mark the edges of the graph.
 
+    verbose : bool
+        If true, a progress bar will be displayed.
+
     Examples
     --------
     >>> import cfpq_data
-    >>> g = cfpq_data.labeled_cycle_graph(42)
-    >>> g.number_of_nodes(), g.number_of_edges()
-    (42, 42)
+    >>> g = cfpq_data.labeled_cycle_graph(42, verbose=False)
+    >>> g.number_of_nodes()
+    42
+    >>> g.number_of_edges()
+    42
 
     Returns
     -------
@@ -43,7 +51,7 @@ def labeled_cycle_graph(
     """
     g = cycle_graph(n=number_of_nodes, create_using=MultiDiGraph)
 
-    for edge in g.edges:
+    for edge in tqdm(g.edges, disable=not verbose, desc="Generation..."):
         g.edges[edge]["label"] = edge_label
 
     return g
