@@ -4,12 +4,16 @@ from typing import Iterable
 
 from networkx import MultiDiGraph
 
-__all__ = [
-    "filter_edges",
-]
+from tqdm import tqdm
+
+__all__ = ["filter_edges"]
 
 
-def filter_edges(graph: MultiDiGraph, labels: Iterable[str]) -> MultiDiGraph:
+def filter_edges(
+    graph: MultiDiGraph,
+    labels: Iterable[str],
+    verbose: bool = True,
+) -> MultiDiGraph:
     """Returns a graph
     with filtered edges.
 
@@ -21,11 +25,14 @@ def filter_edges(graph: MultiDiGraph, labels: Iterable[str]) -> MultiDiGraph:
     labels : Optional[Iterable[str]]
         Graph edge labels to be preserved.
 
+    verbose : bool
+        If true, a progress bar will be displayed.
+
     Examples
     --------
     >>> import cfpq_data
-    >>> g = cfpq_data.labeled_two_cycles_graph(42, 29)
-    >>> new_g = cfpq_data.filter_edges(g, ["a"])
+    >>> g = cfpq_data.labeled_two_cycles_graph(42, 29, edge_labels=("a", "b"), verbose=False)
+    >>> new_g = cfpq_data.filter_edges(g, ["a"], verbose=False)
     >>> new_g.number_of_nodes()
     72
     >>> new_g.number_of_edges()
@@ -41,7 +48,9 @@ def filter_edges(graph: MultiDiGraph, labels: Iterable[str]) -> MultiDiGraph:
     for node, node_labels in graph.nodes(data=True):
         g.add_node(node, **node_labels)
 
-    for u, v, edge_labels in graph.edges(data=True):
+    for u, v, edge_labels in tqdm(
+        graph.edges(data=True), disable=not verbose, desc="Generation..."
+    ):
         filtered_edge_labels = dict()
         for key, value in edge_labels.items():
             if str(value) in labels:
